@@ -3,13 +3,17 @@
 /*
  * stdpccts.h -- P C C T S  I n c l u d e
  *
- * Terence Parr, Will Cohen, and Hank Dietz: 1989-1994
+ * Terence Parr, Will Cohen, and Hank Dietz: 1989-1998
  * Purdue University Electrical Engineering
  * With AHPCRC, University of Minnesota
- * ANTLR Version 1.33MR7
+ * ANTLR Version 1.33MR12b
  */
+
+#ifndef ANTLR_VERSION
+#define ANTLR_VERSION	13312
+#endif
+
 #include <stdio.h>
-#define ANTLR_VERSION	133MR7
 
 #include "config.h"
 #include "set.h"
