@@ -1,13 +1,17 @@
 /*
  * A n t l r  T r a n s l a t i o n  H e a d e r
  *
- * Terence Parr, Will Cohen, and Hank Dietz: 1989-1994
+ * Terence Parr, Will Cohen, and Hank Dietz: 1989-1998
  * Purdue University Electrical Engineering
  * With AHPCRC, University of Minnesota
- * ANTLR Version 1.33MR6
+ * ANTLR Version 1.33MR12b
+ *
+ *   ../bin/antlr dlg_p.g
+ *
  */
+
+#define ANTLR_VERSION	13312
 #include <stdio.h>
-#define ANTLR_VERSION	133MR6
 
 #include <ctype.h>
 #include "dlg.h"
@@ -20,7 +24,7 @@
 #include "dlgdef.h"
 #include "mode.h"
 #ifndef PURIFY
-#define PURIFY(r,s)
+#define PURIFY(r,s) memset((char *) &(r),'\0',(s));
 #endif
 ANTLR_INFO
 
